#ifndef PIECES_ROI_HPP
#define PIECES_ROI_HPP

#include "piece.hpp"

/// Roi dans le jeu d'échec
class Roi : public Piece {
	private:
		/// Définit si le roi est en échec ou non
		bool isChecked = false;

	public:
		/// @brief Vérifie si un mouvement de la case origine à la case destination est valide
		/// @param org Case d'origine
		/// @param dest Destination
		/// @return Vrai si le mouvement est légal, faux sinon
		bool est_mouvement_legal(Square org, Square dest) const override;

		/// Vérifie si la pièce est une menace pour l'adversaire
		/// @param org Position d'origine
		/// @param dest Position de destination
		/// @return true si la pièce est une menace, false sinon
		bool est_menace(Square org, Square dest) const override;

		/// @return Nom de la pièce a affiché sur l'échiquier. Rouge dans le cas où le roi est en échec, blanc sinon
		std::string get_name() const override;

		/// Vérifie si le roi est en échec ou non
		/// @return true si en échec, false sinon
		bool get_is_checked() const { return isChecked; }

		/// Définit si le roi est en échec ou non
		/// @param is_checked true si en échec, false sinon
		void set_is_checked(bool is_checked) { this->isChecked = is_checked; }

		/// @brief Constructeur du roi
		/// @param name Nom de la pièce
		/// @param color Couleur de la pièce
		/// @param id ID de la pièce
		/// @param start_pos Position de départ lors de l'initialisation du jeu
		/// @param echiquier Echiquier où se trouve la pièce
		Roi(std::string name, std::string canon_name, Color color, int id, Square start_pos, Echiquier* const echiquier) : Piece(name, canon_name, color, id, start_pos, echiquier) {
			isChecked = false;
		}
};

#endif