#include <iostream>
#include "jeu.hpp"
#include <regex>

/// Vérifie si la saisie de l'utilisateur est correcte dans le cadre du mouvement d'une pièce
/// @param cmd Commande saisie par l'utilisateur
/// @return Vrai si correcte, faux sinon
bool saisie_correcte(std::string const & cmd) {
	std::regex mouvmtpattern("[a-h][1-8][a-h][1-8]");
    return std::regex_match(cmd,mouvmtpattern);
}

/// Vérifie si la saisie de l'utilisateur est celle d'un petit roque
/// @param cmd Commande saisie par l'utilisateur
/// @return Vrai si correcte, faux sinon
bool saisie_correcte_petitroque(std::string const & cmd) {
	std::regex mouvmtpattern("(O|o|0)-(O|o|0)");
    return regex_match(cmd,mouvmtpattern);
}

/// Vérifie si la saisie de l'utilisateur est celle d'un grand roque
/// @param cmd Commande saisie par l'utilisateur
/// @return Vrai si correcte, faux sinon
bool saisie_correcte_grandroque(std::string const & cmd) {
	std::regex mouvmtpattern("(O|o|0)-(O|o|0)-(O|o|0)");
    return regex_match(cmd,mouvmtpattern);
}

int main(){

	Jeu jeu("Jeu 1");
	bool stop = false;
	std::string command;
	jeu.setup();
	while (!stop)
	{
		// Permet d'effacer le terminal à chaque coup joué.
		std::cout << "\033[H\033[2J\033[3J";
		jeu.print();
		std::cin >> command;

		if(command == "/resign"){
			std::cout << std::endl << jeu.canonical() << (jeu.get_player() == WHITE ? "0-1" : "1-0") << std::endl;
			stop = true;
		}else if(command == "/draw"){
			std::cout << std::endl << jeu.canonical() << "1/2-1/2" << std::endl;
			stop = true;
		}else if(command == "/quit"){
			std::cout << std::endl << jeu.canonical() << "?-?" << std::endl;
			stop = true;
		}else{
			if(saisie_correcte(command)){
				std::string orig = command.substr(0, 2);
				std::string dest = command.substr(2, 2);

				if(!jeu.move(Square(orig), Square(dest)))
					continue;

				switch (jeu.check_status()) {
					case CHECK_MATE:
						std::cout << std::endl << jeu.canonical() << (jeu.get_player() == WHITE ? "0-1" : "1-0") << std::endl;
						stop = true;
						break;
					case ON_GOING:
						break;
					case STALEMATE:
						std::cout << std::endl << jeu.canonical() << "1/2-1/2" << std::endl;
						stop = true;
						break;
				}

				jeu.set_message("Que souhaitez-vous faire ?");
			} else if(saisie_correcte_petitroque(command)) {
				if(!jeu.castling(false)){
					jeu.set_message("Petit roque impossible");
				}
			} else if(saisie_correcte_grandroque(command)) {
				if(!jeu.castling(true)){
					jeu.set_message("Grand roque impossible");
				}
			} else {
				jeu.set_message("Commande invalide");
			}
		}
	}
	
	// exit(0);
	return 0;
}